@@ -9,12 +9,13 @@ from collections import defaultdict
 
 import pylogconf.core
 import yaml
+import jsonschema
 from pytconf import register_endpoint, get_free_args, register_main, config_arg_parse_and_launch
 from tqdm import tqdm
 from lxml import etree
 
 from pycmdtools.configs import ConfigFolder, ConfigUseStandardExceptions, ConfigChangeLine, ConfigProgress, \
-    ConfigAlgorithm, ConfigDownloadGoogleDrive, ConfigCopy, ConfigDownloadGdriveURL
+    ConfigAlgorithm, ConfigDownloadGoogleDrive, ConfigCopy, ConfigDownloadGdriveURL, ConfigOutput
 from pycmdtools.static import DESCRIPTION, APP_NAME, VERSION_STR
 from pycmdtools.utils import yield_bad_symlinks, diamond_lines, checksum, download_file_from_google_drive, error, \
     remove_bad_symlinks, gdrive_download_link
@@ -174,6 +175,19 @@ def validate_yaml() -> None:
             yaml.load(input_handle, yaml.SafeLoader)
 
 
+@register_endpoint(
+    description="Validate jsonschame files",
+    allow_free_args=True,
+    min_free_args=1,
+)
+def validate_jsonschema() -> None:
+    for filename in get_free_args():
+        with open(filename, "rt") as stream:
+            data = json.load(stream)
+            validator = jsonschema.validators.validator_for(data)
+            validator.check_schema(data)
+
+
 @register_endpoint(
     description="Validate XML files",
     allow_free_args=True
@@ -196,6 +210,7 @@ def xprofile_select() -> None:
         ConfigProgress,
         ConfigAlgorithm,
         ConfigCopy,
+        ConfigOutput,
     ],
     allow_free_args=True,
     min_free_args=2,
@@ -215,8 +230,12 @@ def mcmp() -> None:
     for file_name in files:
         check_sum = checksum(file_name=file_name, algorithm=ConfigAlgorithm.algorithm)
         d[check_sum].add(file_name)
-    for i, check_sum in enumerate(sorted(d.keys())):
-        print(f"{i}: {', '.join(sorted(d[check_sum]))}")
+    if ConfigOutput.print is None:
+        for i, check_sum in enumerate(sorted(d.keys())):
+            print(f"{i}: {', '.join(sorted(d[check_sum]))}")
+    else:
+        if len(d.keys()) > 1:
+            print(ConfigOutput.print)
     if ConfigCopy.copy:
         sorted_keys = sorted(d.keys())
         index_from = int(input("From what version? "))
